import { transformError as sdkTransformError } from '@wix/sdk-runtime/transform-error';
import { queryBuilder } from '@wix/sdk-runtime/query-builder';
import { renameKeysFromSDKRequestToRESTRequest, renameKeysFromRESTResponseToSDKResponse, } from '@wix/sdk-runtime/rename-all-nested-keys';
import * as ambassadorWixMembersV1ActivityCounter from './members-v1-activity-counter-activity-counters.http.js';
// @ts-ignore
import { transformPaths } from '@wix/sdk-runtime/transformations/transform-paths';
export var WebhookIdentityType;
(function (WebhookIdentityType) {
    WebhookIdentityType["UNKNOWN"] = "UNKNOWN";
    WebhookIdentityType["ANONYMOUS_VISITOR"] = "ANONYMOUS_VISITOR";
    WebhookIdentityType["MEMBER"] = "MEMBER";
    WebhookIdentityType["WIX_USER"] = "WIX_USER";
    WebhookIdentityType["APP"] = "APP";
})(WebhookIdentityType || (WebhookIdentityType = {}));
/**
 * Sets activity counters for a requested site member.
 *
 * If the counter does not already exist, it will be created.
 *
 * Counters are identified with a custom key, which must be unique.
 *
 * > **Note**: Make sure to pass a `memberId` and not a `contactId` to identify the member. Any relationship between a member's `memberId` and `contactId` is coincidental.
 * @param memberId - Member ID whose counter will be set.
 * @param counter - Counter data for this site member.
 * @public
 * @requiredField counter
 * @requiredField memberId
 * @permissionId MEMBERS.ACTIVITY_COUNTERS_WRITE
 * @permissionScope Manage Activity Counters
 * @permissionScopeId SCOPE.DC-MEMBERS.MANAGE-ACTIVITY-COUNTERS
 * @applicableIdentity APP
 * @fqn com.wixpress.members.activitycounters.ActivityCounters.SetActivityCounters
 */
export async function setActivityCounters(memberId, counter) {
    // @ts-ignore
    const { httpClient, sideEffects } = arguments[2];
    const payload = renameKeysFromSDKRequestToRESTRequest({
        memberId: memberId,
        counter: counter,
    });
    const reqOpts = ambassadorWixMembersV1ActivityCounter.setActivityCounters(payload);
    sideEffects?.onSiteCall?.();
    try {
        const result = await httpClient.request(reqOpts);
        sideEffects?.onSuccess?.(result);
        return renameKeysFromRESTResponseToSDKResponse(result.data);
    }
    catch (err) {
        const transformedError = sdkTransformError(err, {
            spreadPathsToArguments: {},
            explicitPathsToArguments: { memberId: '$[0]', counter: '$[1]' },
            singleArgumentUnchanged: false,
        }, ['memberId', 'counter']);
        sideEffects?.onError?.(err);
        throw transformedError;
    }
}
/**
 * Increments a specific activity counters for a specified site member.
 *
 * If the counter does not already exist, it will be created.
 *
 * Counters are identified with a custom key, which must be unique.
 *
 * > **Note**: Make sure to pass a `memberId` and not a `contactId` to identify the member. Any relationship between a member's `memberId` and `contactId` is coincidental.
 * @param memberId - Member ID whose counter will be incremented.
 * @param counter - Counter data for this site member.
 * @public
 * @requiredField counter
 * @requiredField memberId
 * @permissionId MEMBERS.ACTIVITY_COUNTERS_WRITE
 * @permissionScope Manage Activity Counters
 * @permissionScopeId SCOPE.DC-MEMBERS.MANAGE-ACTIVITY-COUNTERS
 * @applicableIdentity APP
 * @fqn com.wixpress.members.activitycounters.ActivityCounters.IncrementActivityCounters
 */
export async function incrementActivityCounters(memberId, counter) {
    // @ts-ignore
    const { httpClient, sideEffects } = arguments[2];
    const payload = renameKeysFromSDKRequestToRESTRequest({
        memberId: memberId,
        counter: counter,
    });
    const reqOpts = ambassadorWixMembersV1ActivityCounter.incrementActivityCounters(payload);
    sideEffects?.onSiteCall?.();
    try {
        const result = await httpClient.request(reqOpts);
        sideEffects?.onSuccess?.(result);
        return renameKeysFromRESTResponseToSDKResponse(result.data);
    }
    catch (err) {
        const transformedError = sdkTransformError(err, {
            spreadPathsToArguments: {},
            explicitPathsToArguments: { memberId: '$[0]', counter: '$[1]' },
            singleArgumentUnchanged: false,
        }, ['memberId', 'counter']);
        sideEffects?.onError?.(err);
        throw transformedError;
    }
}
/**
 * Retrieves activity counters for the specified site member, including all public counters and any private counters owned by the authenticated caller.
 *
 * > **Note**: Make sure to pass a `memberId` and not a `contactId` to identify the member. Any relationship between a member's `memberId` and `contactId` is coincidental.
 * @param memberId - Member ID whose counters will be returned.
 * @public
 * @requiredField memberId
 * @permissionId MEMBERS.ACTIVITY_COUNTERS_READ
 * @permissionScope Manage Activity Counters
 * @permissionScopeId SCOPE.DC-MEMBERS.MANAGE-ACTIVITY-COUNTERS
 * @permissionScope Read Activity Counters
 * @permissionScopeId SCOPE.DC-MEMBERS.READ-ACTIVITY-COUNTERS
 * @applicableIdentity APP
 * @applicableIdentity VISITOR
 * @fqn com.wixpress.members.activitycounters.ActivityCounters.GetActivityCounters
 */
export async function getActivityCounters(memberId) {
    // @ts-ignore
    const { httpClient, sideEffects } = arguments[1];
    const payload = renameKeysFromSDKRequestToRESTRequest({ memberId: memberId });
    const reqOpts = ambassadorWixMembersV1ActivityCounter.getActivityCounters(payload);
    sideEffects?.onSiteCall?.();
    try {
        const result = await httpClient.request(reqOpts);
        sideEffects?.onSuccess?.(result);
        return renameKeysFromRESTResponseToSDKResponse(result.data);
    }
    catch (err) {
        const transformedError = sdkTransformError(err, {
            spreadPathsToArguments: {},
            explicitPathsToArguments: { memberId: '$[0]' },
            singleArgumentUnchanged: false,
        }, ['memberId']);
        sideEffects?.onError?.(err);
        throw transformedError;
    }
}
/**
 * Returns up to 100 public activity counters for the provided filter and paging.
 *
 * Only counters that are marked as public are returned.
 *
 * Supported fields for filtering:
 * - `memberId`
 *
 * Supported operations:
 *
 * Comparison:
 * - $eq
 * - $ne
 * - $in
 *
 * Logical:
 * - $and
 * - $not
 * - $or
 * @public
 * @param options - Information about the activity counters to retrieve.
 * @permissionScope Manage Activity Counters
 * @permissionScopeId SCOPE.DC-MEMBERS.MANAGE-ACTIVITY-COUNTERS
 * @permissionScope Read Activity Counters
 * @permissionScopeId SCOPE.DC-MEMBERS.READ-ACTIVITY-COUNTERS
 * @permissionId MEMBERS.ACTIVITY_COUNTERS_READ
 * @applicableIdentity APP
 * @applicableIdentity VISITOR
 * @fqn com.wixpress.members.activitycounters.ActivityCounters.QueryActivityCounters
 */
export function queryActivityCounters() {
    // @ts-ignore
    const { httpClient, sideEffects } = arguments[0];
    return queryBuilder({
        func: async (payload) => {
            const reqOpts = ambassadorWixMembersV1ActivityCounter.queryActivityCounters(payload);
            sideEffects?.onSiteCall?.();
            try {
                const result = await httpClient.request(reqOpts);
                sideEffects?.onSuccess?.(result);
                return result;
            }
            catch (err) {
                sideEffects?.onError?.(err);
                throw err;
            }
        },
        requestTransformer: (query) => {
            const args = [query, {}];
            return renameKeysFromSDKRequestToRESTRequest({
                ...args?.[1],
                query: args?.[0],
            });
        },
        responseTransformer: ({ data, }) => {
            const transformedData = renameKeysFromRESTResponseToSDKResponse(transformPaths(data, []));
            return {
                items: transformedData?.activityCounters,
                pagingMetadata: transformedData?.metadata,
            };
        },
        errorTransformer: (err) => {
            const transformedError = sdkTransformError(err, {
                spreadPathsToArguments: {},
                explicitPathsToArguments: { query: '$[0]' },
                singleArgumentUnchanged: false,
            });
            throw transformedError;
        },
        pagingMethod: 'OFFSET',
        transformationPaths: {},
    });
}
//# sourceMappingURL=members-v1-activity-counter-activity-counters.universal.js.map